@@ -13,6 +13,11 @@ DBItest::make_context(
     blob_cast = function(x) paste0("(", x, "::bytea)")
   ),
   default_skip = c(
-    if (packageVersion("DBItest") < "1.7.0.9002") "compliance"
+    if (packageVersion("DBItest") < "1.7.0.9002") "compliance",
+
+    if (packageVersion("DBItest") < "1.7.0.9010") "append_roundtrip_timestamp",
+    if (packageVersion("DBItest") < "1.7.0.9010") "roundtrip_timestamp",
+
+    NULL
   )
 )
